@@ -1,5 +1,5 @@
 #
-# Copyright (c), 2016-2020, SISSA (International School for Advanced Studies).
+# Copyright (c), 2016-2021, SISSA (International School for Advanced Studies).
 # All rights reserved.
 # This file is distributed under the terms of the MIT License.
 # See the file 'LICENSE' in the root directory of the present
@@ -13,14 +13,15 @@ Tests subpackage module: common definitions for unittest scripts of the 'xmlsche
 import unittest
 import re
 import os
+from textwrap import dedent
 
-from ..validators import XMLSchema10
-from ..exceptions import XMLSchemaValueError
-from ..qnames import XSD_SCHEMA
-from ..namespaces import XSD_NAMESPACE, get_namespace
-from ..etree import etree_element, etree_register_namespace, etree_elements_assert_equal
-from ..resources import fetch_namespaces
-from ..helpers import is_etree_element
+from xmlschema.exceptions import XMLSchemaValueError
+from xmlschema.names import XSD_NAMESPACE, XSI_NAMESPACE, XSD_SCHEMA
+from xmlschema.helpers import get_namespace
+from xmlschema.etree import is_etree_element, etree_element
+from xmlschema.resources import fetch_namespaces
+from xmlschema.validators import XMLSchema10
+from .helpers import etree_elements_assert_equal
 
 
 PROTECTED_PREFIX_PATTERN = re.compile(r'\bns\d:')
@@ -37,9 +38,6 @@ class XsdValidatorTestCase(unittest.TestCase):
     TEST_CASES_DIR = None
     schema_class = XMLSchema10
 
-    etree_register_namespace(prefix='xs', uri=XSD_NAMESPACE)
-    etree_register_namespace(prefix='ns', uri="ns")
-
     @classmethod
     def setUpClass(cls):
         cls.errors = []
@@ -97,14 +95,15 @@ class XsdValidatorTestCase(unittest.TestCase):
                 raise XMLSchemaValueError("% is not an XSD global definition/declaration." % source)
 
             root = etree_element('schema', attrib={
-                'xmlns:xs': "http://www.w3.org/2001/XMLSchema",
+                'xmlns:xs': XSD_NAMESPACE,
+                'xmlns:xsi': XSI_NAMESPACE,
                 'elementFormDefault': "qualified",
                 'version': self.schema_class.XSD_VERSION,
             })
             root.append(source)
             return root
         else:
-            source = source.strip()
+            source = dedent(source.strip())
             if not source.startswith('<'):
                 return self.casepath(source)
             elif source.startswith('<?xml ') or source.startswith('<xs:schema '):
@@ -148,7 +147,8 @@ class XsdValidatorTestCase(unittest.TestCase):
         a substring test if it's not `None` (maybe a string). Then returns the schema instance.
         """
         if isinstance(expected, type) and issubclass(expected, Exception):
-            self.assertRaises(expected, self.schema_class, self.get_schema_source(source), **kwargs)
+            with self.assertRaises(expected):
+                self.schema_class(self.get_schema_source(source), **kwargs)
         else:
             schema = self.schema_class(self.get_schema_source(source), **kwargs)
             if callable(expected):
@@ -166,8 +166,8 @@ class XsdValidatorTestCase(unittest.TestCase):
         for e in self.errors:
             error_string = str(e)
             self.assertTrue(e.path, "Missing path for: %s" % error_string)
-            self.assertTrue(e.namespaces, "Missing namespaces for: %s" % error_string)
-            self.check_namespace_prefixes(error_string)
+            if e.namespaces:
+                self.check_namespace_prefixes(error_string)
 
         if not self.errors and expected:
             raise ValueError("{!r}: found no errors when {} expected.".format(path, expected))
